# whittle

A framework for two-stage neural architecture search (NAS) and structural pruning on language models.

## Setup

1. clone this repository: `git clone git@github.com:whittle-org/whittle.git`
2. `cd` into the repository: `cd whittle`
3. Create a new conda environment and activate: `conda create -n whittle python=3.11 -y && conda activate whittle`
4. Install the dependencies: `pip install .`

`Note: the library supports and is tested for python 3.9 to 3.11`

